@@ -84,4 +84,10 @@ LANDING_ZONE_THRESHOLDS = [{'label': 'A',
 
 SECURITY_HUB_FILTER = {'UpdatedAt': [{'DateRange': {'Value': 7,
                                                     'Unit': 'DAYS'}}
-                                     ]}
+                                     ],
+                       'ComplianceStatus': [{'Value': 'FAILED',
+                                             'Comparison': 'EQUALS'}
+                                            ],
+                       'WorkflowStatus': [{'Value': 'SUPPRESSED',
+                                           'Comparison': 'NOT_EQUALS'}
+                                          ]}
